@@ -17,7 +17,7 @@ from collections import OrderedDict
 from distutils import util
 import os
 import re
-from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
@@ -350,15 +350,12 @@ class ConnectionServiceClient(metaclass=ConnectionServiceClientMeta):
                 client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
-                always_use_jwt_access=(
-                    Transport == type(self).get_transport_class("grpc")
-                    or Transport == type(self).get_transport_class("grpc_asyncio")
-                ),
+                always_use_jwt_access=True,
             )
 
     def create_connection(
         self,
-        request: gcbc_connection.CreateConnectionRequest = None,
+        request: Union[gcbc_connection.CreateConnectionRequest, dict] = None,
         *,
         parent: str = None,
         connection: gcbc_connection.Connection = None,
@@ -370,7 +367,7 @@ class ConnectionServiceClient(metaclass=ConnectionServiceClientMeta):
         r"""Creates a new connection.
 
         Args:
-            request (google.cloud.bigquery_connection_v1.types.CreateConnectionRequest):
+            request (Union[google.cloud.bigquery_connection_v1.types.CreateConnectionRequest, dict]):
                 The request object. The request for
                 [ConnectionService.CreateConnection][google.cloud.bigquery.connection.v1.ConnectionService.CreateConnection].
             parent (str):
@@ -448,7 +445,7 @@ class ConnectionServiceClient(metaclass=ConnectionServiceClientMeta):
 
     def get_connection(
         self,
-        request: connection.GetConnectionRequest = None,
+        request: Union[connection.GetConnectionRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -458,7 +455,7 @@ class ConnectionServiceClient(metaclass=ConnectionServiceClientMeta):
         r"""Returns specified connection.
 
         Args:
-            request (google.cloud.bigquery_connection_v1.types.GetConnectionRequest):
+            request (Union[google.cloud.bigquery_connection_v1.types.GetConnectionRequest, dict]):
                 The request object. The request for
                 [ConnectionService.GetConnection][google.cloud.bigquery.connection.v1.ConnectionService.GetConnection].
             name (str):
@@ -520,7 +517,7 @@ class ConnectionServiceClient(metaclass=ConnectionServiceClientMeta):
 
     def list_connections(
         self,
-        request: connection.ListConnectionsRequest = None,
+        request: Union[connection.ListConnectionsRequest, dict] = None,
         *,
         parent: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -530,7 +527,7 @@ class ConnectionServiceClient(metaclass=ConnectionServiceClientMeta):
         r"""Returns a list of connections in the given project.
 
         Args:
-            request (google.cloud.bigquery_connection_v1.types.ListConnectionsRequest):
+            request (Union[google.cloud.bigquery_connection_v1.types.ListConnectionsRequest, dict]):
                 The request object. The request for
                 [ConnectionService.ListConnections][google.cloud.bigquery.connection.v1.ConnectionService.ListConnections].
             parent (str):
@@ -600,7 +597,7 @@ class ConnectionServiceClient(metaclass=ConnectionServiceClientMeta):
 
     def update_connection(
         self,
-        request: gcbc_connection.UpdateConnectionRequest = None,
+        request: Union[gcbc_connection.UpdateConnectionRequest, dict] = None,
         *,
         name: str = None,
         connection: gcbc_connection.Connection = None,
@@ -614,7 +611,7 @@ class ConnectionServiceClient(metaclass=ConnectionServiceClientMeta):
         are in the update field mask.
 
         Args:
-            request (google.cloud.bigquery_connection_v1.types.UpdateConnectionRequest):
+            request (Union[google.cloud.bigquery_connection_v1.types.UpdateConnectionRequest, dict]):
                 The request object. The request for
                 [ConnectionService.UpdateConnection][google.cloud.bigquery.connection.v1.ConnectionService.UpdateConnection].
             name (str):
@@ -694,7 +691,7 @@ class ConnectionServiceClient(metaclass=ConnectionServiceClientMeta):
 
     def delete_connection(
         self,
-        request: connection.DeleteConnectionRequest = None,
+        request: Union[connection.DeleteConnectionRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -704,7 +701,7 @@ class ConnectionServiceClient(metaclass=ConnectionServiceClientMeta):
         r"""Deletes connection and associated credential.
 
         Args:
-            request (google.cloud.bigquery_connection_v1.types.DeleteConnectionRequest):
+            request (Union[google.cloud.bigquery_connection_v1.types.DeleteConnectionRequest, dict]):
                 The request object. The request for
                 [ConnectionService.DeleteConnectionRequest][].
             name (str):
@@ -758,7 +755,7 @@ class ConnectionServiceClient(metaclass=ConnectionServiceClientMeta):
 
     def get_iam_policy(
         self,
-        request: iam_policy_pb2.GetIamPolicyRequest = None,
+        request: Union[iam_policy_pb2.GetIamPolicyRequest, dict] = None,
         *,
         resource: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -770,7 +767,7 @@ class ConnectionServiceClient(metaclass=ConnectionServiceClientMeta):
         not have a policy set.
 
         Args:
-            request (google.iam.v1.iam_policy_pb2.GetIamPolicyRequest):
+            request (Union[google.iam.v1.iam_policy_pb2.GetIamPolicyRequest, dict]):
                 The request object. Request message for `GetIamPolicy`
                 method.
             resource (str):
@@ -885,7 +882,7 @@ class ConnectionServiceClient(metaclass=ConnectionServiceClientMeta):
 
     def set_iam_policy(
         self,
-        request: iam_policy_pb2.SetIamPolicyRequest = None,
+        request: Union[iam_policy_pb2.SetIamPolicyRequest, dict] = None,
         *,
         resource: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -899,7 +896,7 @@ class ConnectionServiceClient(metaclass=ConnectionServiceClientMeta):
         ``PERMISSION_DENIED`` errors.
 
         Args:
-            request (google.iam.v1.iam_policy_pb2.SetIamPolicyRequest):
+            request (Union[google.iam.v1.iam_policy_pb2.SetIamPolicyRequest, dict]):
                 The request object. Request message for `SetIamPolicy`
                 method.
             resource (str):
@@ -1014,7 +1011,7 @@ class ConnectionServiceClient(metaclass=ConnectionServiceClientMeta):
 
     def test_iam_permissions(
         self,
-        request: iam_policy_pb2.TestIamPermissionsRequest = None,
+        request: Union[iam_policy_pb2.TestIamPermissionsRequest, dict] = None,
         *,
         resource: str = None,
         permissions: Sequence[str] = None,
@@ -1032,7 +1029,7 @@ class ConnectionServiceClient(metaclass=ConnectionServiceClientMeta):
         warning.
 
         Args:
-            request (google.iam.v1.iam_policy_pb2.TestIamPermissionsRequest):
+            request (Union[google.iam.v1.iam_policy_pb2.TestIamPermissionsRequest, dict]):
                 The request object. Request message for
                 `TestIamPermissions` method.
             resource (str):
@@ -1101,6 +1098,19 @@ class ConnectionServiceClient(metaclass=ConnectionServiceClientMeta):
         # Done; return the response.
         return response
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, type, value, traceback):
+        """Releases underlying transport's resources.
+
+        .. warning::
+            ONLY use as a context manager if the transport is NOT shared
+            with other clients! Exiting the with block will CLOSE the transport
+            and may cause errors in other clients!
+        """
+        self.transport.close()
+
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
